This project contains a simple Tic-Tac-Toe game. The game is played on a 3x3
grid, where two players take turns to place their marks. The first player to get
three of their marks in a straight line wins the game. You know the rules!

The game has a simple UI with a grid of buttons that represent the game board.
When a player clicks on a button, the corresponding cell is marked with their
symbol. The game checks for a winner after each move and displays a message when
the game is over.
